@@ -1,14 +1,16 @@
 import plotly.express as px
 import plotly.graph_objects as go
-import dash
+import plotly.io as pio
 import numpy as np
 import casadi as cas
 import matplotlib.pyplot as plt
 import matplotlib.style as style
 import seaborn as sns
-
+plt.ion()
 sns.set(font_scale=1)
 
+# Set the rendering to happen in browser
+pio.renderers.default = "browser"
 
 def reflect_over_XZ_plane(input_vector):
     # Takes in a vector or an array and flips the y-coordinates.
